@@ -225,20 +225,28 @@ class Keil5P27Converter(Converter):
                     print('JLink reset type not supported, relevant settings will remain default')
 
                 # 烧写选项
-                jlink_dl_opt = re.search('-FO([0-9]*)', jlink_opt).group(1)
-                dl_erase_index = {
-                    17: 'full chip',
-                    1: 'sectors',
-                    0: 'none',
-                }
-                if int(jlink_dl_opt) in dl_erase_index:
-                    prj_desc['debug']['download']['erase'] = dl_erase_index[int(jlink_dl_opt)]
-                else:
-                    print("JLink erase type not supported, default to \'erase sectors\'")
+                try:
+                    jlink_dl_opt = int(re.search('-FO([0-9]*)', jlink_opt).group(1))
+                    prj_desc['debug']['download']['program'] = bool(jlink_dl_opt & (0b01 << 1) == (0b01 << 1))
+                    prj_desc['debug']['download']['verify'] = bool(jlink_dl_opt & (0b01 << 2) == (0b01 << 2))
+                    prj_desc['debug']['download']['reset-run'] = bool(jlink_dl_opt & (0b01 << 3) == (0b01 << 3))
+                    jlink_dl_opt = jlink_dl_opt & ~0b01110  # 去除标志位
+                    dl_erase_index = {
+                        17: 'full chip',
+                        1: 'sectors',
+                        0: 'none',
+                    }
+                    if jlink_dl_opt in dl_erase_index:
+                        prj_desc['debug']['download']['erase'] = dl_erase_index[jlink_dl_opt]
+                    else:
+                        print("JLink erase type not supported, default to \'erase sectors\'")
+                        prj_desc['debug']['download']['erase'] = 'sectors'
+                except IndexError:
+                    print("JLink download option not found, use default value")
                     prj_desc['debug']['download']['erase'] = 'sectors'
-                prj_desc['debug']['download']['program'] = bool(int(jlink_dl_opt) & (0b01 << 1) == (0b01 << 1))
-                prj_desc['debug']['download']['verify'] = bool(int(jlink_dl_opt) & (0b01 << 2) == (0b01 << 2))
-                prj_desc['debug']['download']['reset-run'] = bool(int(jlink_dl_opt) & (0b01 << 3) == (0b01 << 3))
+                    prj_desc['debug']['download']['program'] = True
+                    prj_desc['debug']['download']['verify'] = True
+                    prj_desc['debug']['download']['reset-run'] = True
 
                 # 工程高级选项 —— flasher configuration
                 jlink_opt_fls = re.findall(
@@ -321,20 +329,28 @@ class Keil5P27Converter(Converter):
                     prj_desc['debug']['speed'] = 8
 
                 # 烧写选项
-                dap_dl_opt = re.search('-FO([0-9]*)', dap_opt).group(1)
-                dl_erase_index = {
-                    17: 'full chip',
-                    1: 'sectors',
-                    0: 'none',
-                }
-                if int(dap_dl_opt) in dl_erase_index:
-                    prj_desc['debug']['download']['erase'] = dl_erase_index[int(dap_dl_opt)]
-                else:
-                    print("CMSIS-DAP erase type not supported, default to \'erase sectors\'")
+                try:
+                    dap_dl_opt = int(re.search('-FO([0-9]*)', dap_opt).group(1))
+                    prj_desc['debug']['download']['program'] = bool(int(dap_dl_opt) & (0b01 << 1) == (0b01 << 1))
+                    prj_desc['debug']['download']['verify'] = bool(int(dap_dl_opt) & (0b01 << 2) == (0b01 << 2))
+                    prj_desc['debug']['download']['reset-run'] = bool(int(dap_dl_opt) & (0b01 << 3) == (0b01 << 3))
+                    dap_dl_opt = dap_dl_opt & ~0b01110  # 去除标志位
+                    dl_erase_index = {
+                        17: 'full chip',
+                        1: 'sectors',
+                        0: 'none',
+                    }
+                    if dap_dl_opt in dl_erase_index:
+                        prj_desc['debug']['download']['erase'] = dl_erase_index[dap_dl_opt]
+                    else:
+                        print("CMSIS-DAP erase type not supported, default to \'erase sectors\'")
+                        prj_desc['debug']['download']['erase'] = 'sectors'
+                except IndexError:
+                    print("CMSIS-DAP download option not found, use default value")
                     prj_desc['debug']['download']['erase'] = 'sectors'
-                prj_desc['debug']['download']['program'] = bool(int(dap_dl_opt) & (0b1 << 1) == (0b01 << 1))
-                prj_desc['debug']['download']['verify'] = bool(int(dap_dl_opt) & (0b1 << 2) == (0b01 << 2))
-                prj_desc['debug']['download']['reset-run'] = bool(int(dap_dl_opt) & (0b1 << 3) == (0b01 << 3))
+                    prj_desc['debug']['download']['program'] = True
+                    prj_desc['debug']['download']['verify'] = True
+                    prj_desc['debug']['download']['reset-run'] = True
 
                 # 工程高级选项 —— flasher configuration
                 dap_opt_fls = re.findall(
@@ -358,11 +374,14 @@ class Keil5P27Converter(Converter):
         # 编译器全局定义
         try:
             defines = target_obj['TargetOption']['TargetArmAds']['Cads']['VariousControls']['Define']
-            define_list = str.split(defines, ",")
-            for define in define_list:
-                if define in target_chip['defines']:
-                    define_list.remove(define)
-            prj_desc['defines'] = define_list
+            if defines is not None:
+                define_list = str.split(defines, ",")
+                for define in define_list:
+                    if define in target_chip['defines']:
+                        define_list.remove(define)
+                prj_desc['defines'] = define_list
+            else:
+                prj_desc['defines'] = []
         except KeyError:
             print('Target has no \'Defines\', default to an empty list')
             prj_desc['defines'] = []
@@ -370,8 +389,11 @@ class Keil5P27Converter(Converter):
         # 包含路径
         try:
             includes = target_obj['TargetOption']['TargetArmAds']['Cads']['VariousControls']['IncludePath']
-            include_list = str.split(includes, ';')
-            prj_desc['includePaths'] = include_list
+            if includes is not None:
+                include_list = str.split(includes, ';')
+                prj_desc['includePaths'] = include_list
+            else:
+                prj_desc['includePaths'] = []
         except KeyError:
             print('Target has no \'Includes\', default to an empty list')
             prj_desc['includePaths'] = []
@@ -379,11 +401,14 @@ class Keil5P27Converter(Converter):
         # 编译器全局定义(ASM)
         try:
             defines = target_obj['TargetOption']['TargetArmAds']['Aads']['VariousControls']['Define']
-            define_list = str.split(defines, ",")
-            for define in define_list:
-                if define in target_chip['defines']:
-                    define_list.remove(define)
-            prj_desc['definesASM'] = define_list
+            if defines is not None:
+                define_list = str.split(defines, ",")
+                for define in define_list:
+                    if define in target_chip['defines']:
+                        define_list.remove(define)
+                prj_desc['definesASM'] = define_list
+            else:
+                prj_desc['definesASM'] = []
         except KeyError:
             print('Target has no \'Defines(ASM)\', default to an empty list')
             prj_desc['definesASM'] = []
@@ -391,8 +416,11 @@ class Keil5P27Converter(Converter):
         # 包含路径(ASM)
         try:
             includes = target_obj['TargetOption']['TargetArmAds']['Aads']['VariousControls']['IncludePath']
-            include_list = str.split(includes, ';')
-            prj_desc['includePathsASM'] = include_list
+            if includes is not None:
+                include_list = str.split(includes, ';')
+                prj_desc['includePathsASM'] = include_list
+            else:
+                prj_desc['includePathsASM'] = []
         except KeyError:
             print('Target has no \'Includes(ASM)\', default to an empty list')
             prj_desc['includePathsASM'] = []
